package com.yunzhi.inte.controller;

import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.DateUtils;
import com.yunzhi.inte.common.ResponseBean;
import com.yunzhi.inte.service.GuaranteeTaskService;
import com.yunzhi.inte.service.StoreService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.Duration;
import java.time.LocalDateTime;
import java.time.temporal.ChronoUnit;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Api(tags = "统计功能接口")
@RestController
@RequestMapping("/statis")
public class StatisController extends BaseController {

    @Autowired
    GuaranteeTaskService guaranteeTaskService;

    @Autowired
    StoreService storeService;

    @ApiOperation("汇总统计")
    @GetMapping("/summary")
    public ResponseBean getSummary() {

        // 任务总数
        Integer taskCount = guaranteeTaskService.total();
        // 接待军人总数
        Integer personNum = guaranteeTaskService.sumPerson();
        // 总体评价
        String evaValue = "良";
        // 设备数量
        Integer deviceNum = storeService.countDevice();

        return ResponseBean.success(new HashMap<String, Object>(){{
            put("taskCount", taskCount);
            put("personNum", personNum);
            put("evaValue", evaValue);
            put("deviceNum", deviceNum);
        }});
    }


    @ApiOperation("任务汇总")
    @GetMapping("/taskInfo")
    public ResponseBean getTaskInfo(@ApiParam("起始日期") @RequestParam(value ="startDate") String startDate,
                                    @ApiParam("起始日期") @RequestParam(value ="endDate") String endDate) {

        LocalDateTime dt1 = DateUtils.day2LocalDateime(startDate);
        LocalDateTime dt2 = DateUtils.day2LocalDateime(endDate);

        Long days = ChronoUnit.DAYS.between(dt1, dt2) + 1;

        List<Map<String, Object>> result;
        if (days < 180) {
            result = guaranteeTaskService.countByDays(startDate, endDate, days);
        } else {
            long months = ChronoUnit.MONTHS.between(dt1, dt2) + 1;
            result = guaranteeTaskService.countByMonths(startDate, endDate, months);
        }

        return ResponseBean.success(result);
    }
}
